==> kea-devel-docs-1.5.0-2.0-any.pkg.tar.zst: usr/share/doc/kea/devel/d5/d35/db__log_8h.js <==
var db__log_8h =
[
    [ "DbLogger", "df/dc1/classisc_1_1db_1_1DbLogger.html", "df/dc1/classisc_1_1db_1_1DbLogger" ],
    [ "DB_LOG_DEBUG", "d5/d35/db__log_8h.html#a8f8789e9f402965c49d2f2c5cc1bea34", null ],
    [ "DB_LOG_ERROR", "d5/d35/db__log_8h.html#a3eaef91f8f234bb8e3e5bf375f2888cf", null ],
    [ "DB_LOG_FATAL", "d5/d35/db__log_8h.html#a5b1ee904949df4e24d132b5e3efa185f", null ],
    [ "DB_LOG_INFO", "d5/d35/db__log_8h.html#af7059807be524f228b4a00f8b11b4c21", null ],
    [ "DB_LOG_WARN", "d5/d35/db__log_8h.html#ac839678788a0c29505adf0c1c9ca395f", null ],
    [ "DbLoggerStack", "d5/d35/db__log_8h.html#a1c65cccec71e67743d0049e0e5de1569", null ],
    [ "DbMessageID", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8b", [
      [ "DB_INVALID_ACCESS", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8ba0013ed55293a029f07780b3e2e9e3eb3", null ],
      [ "PGSQL_DEALLOC_ERROR", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8badf49dfc57059dfccb186146d4960c5ee", null ],
      [ "PGSQL_FATAL_ERROR", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8bab6aa830619ad88caef3e5cda792156d5", null ],
      [ "PGSQL_START_TRANSACTION", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8ba73dd675802f68bdd1971bd000878e003", null ],
      [ "PGSQL_COMMIT", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8ba69ddf265d443c86978422612125697fa", null ],
      [ "PGSQL_ROLLBACK", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8ba3812b237336d39ce2a8713ed2c72c173", null ],
      [ "MYSQL_FATAL_ERROR", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8baecf3fe21221b5c9d320799601a7edfc6", null ],
      [ "MYSQL_START_TRANSACTION", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8ba135cf7f4900c3454f2779a315b0235bb", null ],
      [ "MYSQL_COMMIT", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8baf5f0f7e4f825a61a3a61fbf2ead2a612", null ],
      [ "MYSQL_ROLLBACK", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8bab8356865ffa4bc8571000039f76aa8a2", null ],
      [ "CQL_DEALLOC_ERROR", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8ba4ed0494ceb2fe149a5f84ccf62ed5118", null ],
      [ "CQL_CONNECTION_BEGIN_TRANSACTION", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8ba100a2b14f530949fd4045f77781048c4", null ],
      [ "CQL_CONNECTION_COMMIT", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8ba038479627f73556610d97933e4aed3a5", null ],
      [ "CQL_CONNECTION_ROLLBACK", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8ba973502f6b8b444a59092c70a7add1584", null ]
    ] ],
    [ "checkDbLoggerStack", "d5/d35/db__log_8h.html#ab973435c5ff3569c774d9bcd9752f01c", null ]
];

==> kea-devel-docs-1.5.0-2.1-any.pkg.tar.zst: usr/share/doc/kea/devel/d5/d35/db__log_8h.js <==
var db__log_8h =
[
    [ "isc::db::DbLogger", "df/dc1/classisc_1_1db_1_1DbLogger.html", "df/dc1/classisc_1_1db_1_1DbLogger" ],
    [ "DB_LOG_DEBUG", "d5/d35/db__log_8h.html#a8f8789e9f402965c49d2f2c5cc1bea34", null ],
    [ "DB_LOG_ERROR", "d5/d35/db__log_8h.html#a3eaef91f8f234bb8e3e5bf375f2888cf", null ],
    [ "DB_LOG_FATAL", "d5/d35/db__log_8h.html#a5b1ee904949df4e24d132b5e3efa185f", null ],
    [ "DB_LOG_INFO", "d5/d35/db__log_8h.html#af7059807be524f228b4a00f8b11b4c21", null ],
    [ "DB_LOG_WARN", "d5/d35/db__log_8h.html#ac839678788a0c29505adf0c1c9ca395f", null ],
    [ "DbLoggerStack", "d5/d35/db__log_8h.html#a1c65cccec71e67743d0049e0e5de1569", null ],
    [ "DbMessageID", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8b", [
      [ "DB_INVALID_ACCESS", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8ba0013ed55293a029f07780b3e2e9e3eb3", null ],
      [ "PGSQL_DEALLOC_ERROR", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8badf49dfc57059dfccb186146d4960c5ee", null ],
      [ "PGSQL_FATAL_ERROR", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8bab6aa830619ad88caef3e5cda792156d5", null ],
      [ "PGSQL_START_TRANSACTION", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8ba73dd675802f68bdd1971bd000878e003", null ],
      [ "PGSQL_COMMIT", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8ba69ddf265d443c86978422612125697fa", null ],
      [ "PGSQL_ROLLBACK", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8ba3812b237336d39ce2a8713ed2c72c173", null ],
      [ "MYSQL_FATAL_ERROR", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8baecf3fe21221b5c9d320799601a7edfc6", null ],
      [ "MYSQL_START_TRANSACTION", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8ba135cf7f4900c3454f2779a315b0235bb", null ],
      [ "MYSQL_COMMIT", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8baf5f0f7e4f825a61a3a61fbf2ead2a612", null ],
      [ "MYSQL_ROLLBACK", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8bab8356865ffa4bc8571000039f76aa8a2", null ],
      [ "CQL_DEALLOC_ERROR", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8ba4ed0494ceb2fe149a5f84ccf62ed5118", null ],
      [ "CQL_CONNECTION_BEGIN_TRANSACTION", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8ba100a2b14f530949fd4045f77781048c4", null ],
      [ "CQL_CONNECTION_COMMIT", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8ba038479627f73556610d97933e4aed3a5", null ],
      [ "CQL_CONNECTION_ROLLBACK", "d5/d35/db__log_8h.html#a2c3a15b100e123134e558b3f2c73dc8ba973502f6b8b444a59092c70a7add1584", null ]
    ] ],
    [ "checkDbLoggerStack", "d5/d35/db__log_8h.html#ab973435c5ff3569c774d9bcd9752f01c", null ]
];
